package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbTeacher;
import com.ruoyi.hezhi.domain.vo.TeacherDetailVO;
import com.ruoyi.hezhi.domain.vo.TeacherVO;

import java.util.List;
import java.util.Map;

/**
 * 教师Service接口
 *
 * @author ruoyi
 * @date 2024-09-14
 */
public interface ITbTeacherService
{
    /**
     * 查询教师
     *
     * @param teacherId 教师主键
     * @return 教师
     */
    public TbTeacher selectTbTeacherByTeacherId(Long teacherId);

    /**
     * 查询教师列表
     *
     * @param tbTeacher 教师
     * @return 教师集合
     */
    public List<TbTeacher> selectTbTeacherList(TbTeacher tbTeacher);

    /**
     * 查询师资课程列表
     *
     * @param params
     * @return 教师集合
     */
    public List<Map> selectTbTeacherCourseList(Map<String, Object> params);

    /**
     * 新增教师
     *
     * @param tbTeacher 教师
     * @return 结果
     */
    public int insertTbTeacher(TbTeacher tbTeacher);

    /**
     * 修改教师
     *
     * @param tbTeacher 教师
     * @return 结果
     */
    public int updateTbTeacher(TbTeacher tbTeacher);

    /**
     * 批量删除教师
     *
     * @param teacherIds 需要删除的教师主键集合
     * @return 结果
     */
    public int deleteTbTeacherByTeacherIds(Long[] teacherIds);

    /**
     * 删除教师信息
     *
     * @param teacherId 教师主键
     * @return 结果
     */
    public int deleteTbTeacherByTeacherId(Long teacherId);

    /**
     * 案例list
     * @param typeId 类型id 0全部
     * @return
     */
    public List<TeacherVO> selectTeacherListByType(Long typeId);

    /**
     * 详情
     * @param id
     * @return
     */
    public TeacherDetailVO getDetail(Long id);

    /**
     * 师资团队列表
     *
     * @param params 参数
     * @return 师资团队列表
     */
    public List<Map<String, Object>> getTeacherList(Map<String, Object> params);

    /**
     * 老师详情
     *
     * @param params 参数
     * @return 老师详情
     */
    public Map<String, Object> getTeacherInfo(Map<String, Object> params);
}
